# Basis
# Bei Eingabe keiner Zahl soll eine 0 ausgegeben werden
# Bei Eingabe einer 1 soll 1 ausgegeben werden
# Bei Eingabe einer 3,4 soll 7 ausgegeben werden
# Bei Eingabe einer 10,20 soll 30 ausgegeben werden
#Feature1 Längere Zahlenfolge
# Bei Eingabe einer 1,2,3 soll 6 ausgegeben werden
# Bei Eingabe einer 10,20,30,40 soll 100 ausgegeben werden
#Feature2 Neues Trennzeichen neben dem Komma
# Bei Eingabe von 1\n2,3 soll 6 ausgegeben werden
# Bei Eingabe von 10\n20\n30 soll 60 ausgegeben werden
#Feature3 Negative Zahlen ausschließen
# Bei Eingabe von 1, -2, 3 soll ein Error erscheinen "Negative nicht erlaubt: [-2]
# Bei Eingabe von -10\n -20, -30 soll ein Error erscheinen "Negative nicht erlaubt: [-10,-20,30]
#Feature4 Eigene Trennzeichen eingeben
# Bei Eingabe eines neuen Trennzeichen ";" //;\n1;2 soll 3 ausgegeben werden
# Bei Eingabe eines neuen Trennzeichen "x" //-\n7x8\n9 soll 24 ausgegeben werden
# Bei Eingabe eines neuen Trennzeichens ";" ohne vollständigen Ausdrück //;1;2 soll Ungültiges Format: Nicht vollständig
#Feature5 Zahlen größer 1000 nicht erkennen
# Bei Eingabe von 2,1001 soll 2 ausgegeben werden
# Bei Eingabe von 1002, 50200 soll 0 asugegeben werden
#Feature6 Begrenzungszeichen beliebig lang
# Bei Eingabe von //[**]\n1**2**3 soll 6 ausgegeben werden
# Bei Eingabe von //[###]\n10###20###30 soll 60 ausgegeben werden

'''
Eigener Code:
import unittest
from src.interfaces import IStringCalculator
from src.stringcalculator import StringCalculator

Orlandos Code:
import unittest
from others.Orlando.OrlandoInterfaces import IStringCalculator
from others.Orlando.OrlandoStringCalculator import StringCalculator

import unittest
from others.Dani.DaniStringCalculator import IStringCalculator, StringCalculator

import unittest
from others.Wasili.WasiliStringCalculator import IStringCalculator, StringCalculator

import unittest
from others.Momo.MomoStringCalculator import StringCalculator

import unittest
from others.Alma.AlmaStringCalculator import IStringCalculator, StringCalculator
'''
import unittest
from others.Marvin.MarvinStringCalculator import StringCalculator

class TestStringCalculator(unittest.TestCase):
    def setUp(self):
        self.calculator: IStringCalculator = StringCalculator()  # Zugriff über das Interface

    def test_add_empty_string(self):
        self.assertEqual(self.calculator.add(""), 0)

    def test_add_single_number(self):
        self.assertEqual(self.calculator.add("1"), 1)

    def test_add_two_numbers(self):
        self.assertEqual(self.calculator.add("10,20"), 30)

    def test_add_multiple_numbers(self):
        self.assertEqual(self.calculator.add("1,2,3"), 6)
        self.assertEqual(self.calculator.add("10,20,30,40"), 100)

    def test_add_with_newline_separator(self):
        self.assertEqual(self.calculator.add("1\n2,3"), 6)
        self.assertEqual(self.calculator.add("10\n20\n30"), 60)

    def test_add_single_negative_number(self):
        with self.assertRaises(ValueError) as context:
            self.calculator.add("1,-2,3")
        print(str(context.exception))
        self.assertEqual(str(context.exception), "Negative nicht erlaubt: [-2]")

    def test_add_multiple_negative_numbers(self):
        with self.assertRaises(ValueError) as context:
            self.calculator.add("-10\n-20,-30")
        print(str(context.exception))
        self.assertEqual(str(context.exception), "Negative nicht erlaubt: [-10, -20, -30]")

    def test_add_with_custom_delimiter(self):
        self.assertEqual(self.calculator.add("//;\n1;2"), 3)
        self.assertEqual(self.calculator.add("//x\n7x8\n9"), 24)

    def test_invalid_custom_delimiter_format(self):
        with self.assertRaises(ValueError) as context:
            self.calculator.add("//;1;2")
        print(str(context.exception))

    def test_ignore_numbers_greater_than_1000(self):
        self.assertEqual(self.calculator.add("2,1001"), 2)
        self.assertEqual(self.calculator.add("1002,50200"), 0)

    def test_add_with_custom_delimiter_multiple_characters(self):
        self.assertEqual(self.calculator.add("//[**]\n1**2**3"), 6)
        self.assertEqual(self.calculator.add("//[###]\n10###20###30"), 60)

if __name__ == "__main__":
    unittest.main()

# python -m unittest tests.testStringcalculator -v
# python -m unittest discover -s tests -v